powered by
Rt estimation algorithm configuration
configure_rt_admm( rho = -1, alpha = 0.5, gamma = 0.9, tolerance = 1e-04, maxiter_newton = 50L, maxiter_line = 20L, verbose = 0, ... )
a list of model parameters with class rt_admm_configuration
rt_admm_configuration
Double. An ADMM parameter; coefficient of augmented term in the Lagrangian function.
Double. A parameter adjusting upper bound in line search algorithm in prox_newton algorithm.
prox_newton
Double. A parameter adjusting step size in line search algorithm in prox_newton algorithm.
Double. Tolerance of ADMM convergence.
Integer. Maximum number of iterations for the outer Newton iteration.
Integer. Maximum number of iterations for the linesearch algorithm in the proximal Newton method.
Integer.
space for future extensions
configure_rt_admm() configure_rt_admm(tolerance = 1e-6, verbose = 1L)
Run the code above in your browser using DataLab