discretize_gamma: Compute the discretized density function for gamma distribution
Description
The serial interval distribution expresses the probability of the
symptom onset of a secondary infection occurred a given number of days after
the primary infection. The serial interval distribution is commonly
represented by a discretized Gamma distribution in literature, parametrized
by the shape and scale parameters.